# Copyright 2009 Canonical Ltd.
#
# This file is part of desktopcouch.
#
#  desktopcouch is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License version 3
# as published by the Free Software Foundation.
#
# desktopcouch is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with desktopcouch.  If not, see <http://www.gnu.org/licenses/>.
#
# Authors: Rick Spencer <rick.spencer@canonical.com>

"""Tests for the couchwidget object"""

from testtools import TestCase
from desktopcouch.records.server import CouchDatabase
from desktopcouch.records.couchwidget import CouchWidget

class TestCouchWidget(TestCase):
    """Test the CouchWidget functionality"""
    def setUp(self):
        self.dbname = "couch_widget_test"
        self.record_type = "test_record_type"

    def test_headings_first(self):
        #create a test widget with test database values
        cw = CouchWidget()
        cw.database = self.dbname

        #allow editing
        cw.editable = True

        #create headers/keys
        cw.headings = ["Key1","Key2","Key3","Key4"]

        #set the record_type for the TreeView
        #it will not populate without this value being set
        cw.record_type = self.record_type

        #create a row with all four columns set
        cw.append_row(["val1","val2","val3","val4"])

        #create a row with only the second column set
        cw.append_row(["","val2"])

        #create an empty row (which will not be saved until the user edits it)
        cw.append_row([])

        self.assertEqual(cw.record_type, self.record_type)
        self.__delete_db()

    def test_record_type_first(self):
        #create a test widget with test database values
        cw = CouchWidget()
        cw.database = self.dbname

        #allow editing
        cw.editable = True

        #set the record_type for the TreeView
        #it will not populate without this value being set
        cw.record_type = self.record_type

        #create headers/keys
        cw.headings = ["Key1","Key2","Key3","Key4"]

        #create a row with all four columns set
        cw.append_row(["val1","val2","val3","val4"])

        #create a row with only the second column set
        cw.append_row(["","val2"])

        #create an empty row (which will not be saved until the user edits it)
        cw.append_row([])

        self.assertEqual(cw.record_type, self.record_type)
        self.__delete_db()        

    def tearDown(self):
        """tear down each test"""
        self.__delete_db()
        #delete the database

    def __delete_db(self):
        db = CouchDatabase(self.dbname, create=True)
        del db._server[self.dbname]

      
